@@ -31,6 +31,11 @@
 #ifndef __COGL_PRIMITIVE_H__
 #define __COGL_PRIMITIVE_H__
 
+/* We forward declare the CoglPrimitive type here to avoid some circular
+ * dependency issues with the following headers.
+ */
+typedef struct _CoglPrimitive CoglPrimitive;
+
 #include <cogl/cogl-vertex-buffer.h> /* for CoglVerticesMode */
 #include <cogl/cogl-attribute.h>
 
@@ -44,8 +49,6 @@ G_BEGIN_DECLS
  * FIXME
  */
 
-typedef struct _CoglPrimitive CoglPrimitive;
-
 /**
  * CoglVertexP2:
  * @x: The x component of a position attribute
@@ -244,6 +247,7 @@ cogl_primitive_new_with_attributes (CoglVerticesMode mode,
 
 /**
  * cogl_primitive_new_p2:
+ * @context: A #CoglContext
  * @mode: A #CoglVerticesMode defining how to draw the vertices
  * @n_vertices: The number of vertices to read from @data and also
  *              the number of vertices to read when later drawing.
@@ -289,12 +293,14 @@ cogl_primitive_new_with_attributes (CoglVerticesMode mode,
  * Stability: Unstable
  */
 CoglPrimitive *
-cogl_primitive_new_p2 (CoglVerticesMode mode,
+cogl_primitive_new_p2 (CoglContext *context,
+                       CoglVerticesMode mode,
                        int n_vertices,
                        const CoglVertexP2 *data);
 
 /**
  * cogl_primitive_new_p3:
+ * @context: A #CoglContext
  * @mode: A #CoglVerticesMode defining how to draw the vertices
  * @n_vertices: The number of vertices to read from @data and also
  *              the number of vertices to read when later drawing.
@@ -340,12 +346,14 @@ cogl_primitive_new_p2 (CoglVerticesMode mode,
  * Stability: Unstable
  */
 CoglPrimitive *
-cogl_primitive_new_p3 (CoglVerticesMode mode,
+cogl_primitive_new_p3 (CoglContext *context,
+                       CoglVerticesMode mode,
                        int n_vertices,
                        const CoglVertexP3 *data);
 
 /**
  * cogl_primitive_new_p2c4:
+ * @context: A #CoglContext
  * @mode: A #CoglVerticesMode defining how to draw the vertices
  * @n_vertices: The number of vertices to read from @data and also
  *              the number of vertices to read when later drawing.
@@ -393,12 +401,14 @@ cogl_primitive_new_p3 (CoglVerticesMode mode,
  * Stability: Unstable
  */
 CoglPrimitive *
-cogl_primitive_new_p2c4 (CoglVerticesMode mode,
+cogl_primitive_new_p2c4 (CoglContext *context,
+                         CoglVerticesMode mode,
                          int n_vertices,
                          const CoglVertexP2C4 *data);
 
 /**
  * cogl_primitive_new_p3c4:
+ * @context: A #CoglContext
  * @mode: A #CoglVerticesMode defining how to draw the vertices
  * @n_vertices: The number of vertices to read from @data and also
  *              the number of vertices to read when later drawing.
@@ -446,12 +456,14 @@ cogl_primitive_new_p2c4 (CoglVerticesMode mode,
  * Stability: Unstable
  */
 CoglPrimitive *
-cogl_primitive_new_p3c4 (CoglVerticesMode mode,
+cogl_primitive_new_p3c4 (CoglContext *context,
+                         CoglVerticesMode mode,
                          int n_vertices,
                          const CoglVertexP3C4 *data);
 
 /**
  * cogl_primitive_new_p2t2:
+ * @context: A #CoglContext
  * @mode: A #CoglVerticesMode defining how to draw the vertices
  * @n_vertices: The number of vertices to read from @data and also
  *              the number of vertices to read when later drawing.
@@ -499,12 +511,14 @@ cogl_primitive_new_p3c4 (CoglVerticesMode mode,
  * Stability: Unstable
  */
 CoglPrimitive *
-cogl_primitive_new_p2t2 (CoglVerticesMode mode,
+cogl_primitive_new_p2t2 (CoglContext *context,
+                         CoglVerticesMode mode,
                          int n_vertices,
                          const CoglVertexP2T2 *data);
 
 /**
  * cogl_primitive_new_p3t2:
+ * @context: A #CoglContext
  * @mode: A #CoglVerticesMode defining how to draw the vertices
  * @n_vertices: The number of vertices to read from @data and also
  *              the number of vertices to read when later drawing.
@@ -552,12 +566,14 @@ cogl_primitive_new_p2t2 (CoglVerticesMode mode,
  * Stability: Unstable
  */
 CoglPrimitive *
-cogl_primitive_new_p3t2 (CoglVerticesMode mode,
+cogl_primitive_new_p3t2 (CoglContext *context,
+                         CoglVerticesMode mode,
                          int n_vertices,
                          const CoglVertexP3T2 *data);
 
 /**
  * cogl_primitive_new_p2t2c4:
+ * @context: A #CoglContext
  * @mode: A #CoglVerticesMode defining how to draw the vertices
  * @n_vertices: The number of vertices to read from @data and also
  *              the number of vertices to read when later drawing.
@@ -605,12 +621,14 @@ cogl_primitive_new_p3t2 (CoglVerticesMode mode,
  * Stability: Unstable
  */
 CoglPrimitive *
-cogl_primitive_new_p2t2c4 (CoglVerticesMode mode,
+cogl_primitive_new_p2t2c4 (CoglContext *context,
+                           CoglVerticesMode mode,
                            int n_vertices,
                            const CoglVertexP2T2C4 *data);
 
 /**
  * cogl_primitive_new_p3t2c4:
+ * @context: A #CoglContext
  * @mode: A #CoglVerticesMode defining how to draw the vertices
  * @n_vertices: The number of vertices to read from @data and also
  *              the number of vertices to read when later drawing.
@@ -658,7 +676,8 @@ cogl_primitive_new_p2t2c4 (CoglVerticesMode mode,
  * Stability: Unstable
  */
 CoglPrimitive *
-cogl_primitive_new_p3t2c4 (CoglVerticesMode mode,
+cogl_primitive_new_p3t2c4 (CoglContext *context,
+                           CoglVerticesMode mode,
                            int n_vertices,
                            const CoglVertexP3T2C4 *data);
 int
@@ -775,16 +794,32 @@ cogl_primitive_set_indices (CoglPrimitive *primitive,
                             int n_indices);
 
 /**
- * cogl_primitive_draw:
- * @primitive: A #CoglPrimitive object
+ * cogl_primitive_get_indices:
+ * @primitive: A #CoglPrimitive
  *
- * Draw the given @primitive with the current source material.
+ * Return value: the indices that were set with
+ * cogl_primitive_set_indices() or %NULL if no indices were set.
  *
- * Since: 1.6
- * Stability: Unstable
+ * Since: 1.10
+ * Stability: unstable
  */
-void
-cogl_primitive_draw (CoglPrimitive *primitive);
+CoglIndices *
+cogl_primitive_get_indices (CoglPrimitive *primitive);
+
+/**
+ * cogl_primitive_copy:
+ * @primitive: A primitive copy
+ *
+ * Makes a copy of an existing #CoglPrimitive. Note that the primitive
+ * is a shallow copy which means it will use the same attributes and
+ * attribute buffers as the original primitive.
+ *
+ * Return value: the new primitive
+ * Since: 1.10
+ * Stability: unstable
+ */
+CoglPrimitive *
+cogl_primitive_copy (CoglPrimitive *primitive);
 
 /**
  * cogl_is_primitive:
@@ -801,6 +836,41 @@ cogl_primitive_draw (CoglPrimitive *primitive);
 gboolean
 cogl_is_primitive (void *object);
 
+/**
+ * CoglPrimitiveAttributeCallback:
+ * @primitive: The #CoglPrimitive whose attributes are being iterated
+ * @attribute: The #CoglAttribute
+ * @user_data: The private data passed to cogl_primitive_foreach_attribute()
+ *
+ * The callback prototype used with cogl_primitive_foreach_attribute()
+ * for iterating all the attributes of a #CoglPrimitive.
+ *
+ * The function should return TRUE to continue iteration or FALSE to
+ * stop.
+ *
+ * Since: 1.10
+ * Stability: Unstable
+ */
+typedef gboolean (* CoglPrimitiveAttributeCallback) (CoglPrimitive *primitive,
+                                                     CoglAttribute *attribute,
+                                                     void *user_data);
+
+/**
+ * cogl_primitive_foreach_attribute:
+ * @primitive: A #CoglPrimitive object
+ * @callback: A #CoglPrimitiveAttributeCallback to be called for each attribute
+ * @user_data: Private data that will be passed to the callback
+ *
+ * Iterates all the attributes of the given #CoglPrimitive.
+ *
+ * Since: 1.10
+ * Stability: Unstable
+ */
+void
+cogl_primitive_foreach_attribute (CoglPrimitive *primitive,
+                                  CoglPrimitiveAttributeCallback callback,
+                                  void *user_data);
+
 G_END_DECLS
 
 #endif /* __COGL_PRIMITIVE_H__ */
