@@ -44,16 +44,6 @@ _cogl_check_extension (const char *name, const char *ext);
 void
 _cogl_clear (const CoglColor *color, unsigned long buffers);
 
-void
-_cogl_read_pixels_with_rowstride (int x,
-                                  int y,
-                                  int width,
-                                  int height,
-                                  CoglReadPixelsFlags source,
-                                  CoglPixelFormat format,
-                                  guint8 *pixels,
-                                  int rowstride);
-
 void
 _cogl_init (void);
 
@@ -102,6 +92,18 @@ _cogl_pixel_format_get_bytes_per_pixel (CoglPixelFormat format);
 gboolean
 _cogl_pixel_format_is_endian_dependant (CoglPixelFormat format);
 
+/*
+ * COGL_PIXEL_FORMAT_CAN_HAVE_PREMULT(format):
+ * @format: a #CoglPixelFormat
+ *
+ * Returns TRUE if the pixel format can take a premult bit. This is
+ * currently true for all formats that have an alpha channel except
+ * COGL_PIXEL_FORMAT_A_8 (because that doesn't have any other
+ * components to multiply by the alpha).
+ */
+#define COGL_PIXEL_FORMAT_CAN_HAVE_PREMULT(format) \
+  (((format) & COGL_A_BIT) && (format) != COGL_PIXEL_FORMAT_A_8)
+
 G_END_DECLS
 
 #endif /* __COGL_PRIVATE_H__ */
