@@ -130,7 +130,7 @@ cogl_shader_source (CoglHandle   handle,
   if (!cogl_is_shader (handle))
     return;
 
-  shader = _cogl_shader_pointer_from_handle (handle);
+  shader = handle;
 
 #ifdef HAVE_COGL_GL
   if (strncmp (source, "!!ARBfp1.0", 10) == 0)
@@ -384,6 +384,7 @@ _cogl_shader_compile_real (CoglHandle handle,
           g_warning ("Failed to compile GLSL program:\nsrc:\n%s\nerror:\n%s\n",
                      shader->source,
                      log);
+          g_free (log);
         }
 #endif
     }
@@ -399,7 +400,7 @@ cogl_shader_get_info_log (CoglHandle handle)
   if (!cogl_is_shader (handle))
     return NULL;
 
-  shader = _cogl_shader_pointer_from_handle (handle);
+  shader = handle;
 
 #ifdef HAVE_COGL_GL
   if (shader->language == COGL_SHADER_LANGUAGE_ARBFP)
@@ -450,7 +451,7 @@ cogl_shader_get_type (CoglHandle  handle)
       return COGL_SHADER_TYPE_VERTEX;
     }
 
-  shader = _cogl_shader_pointer_from_handle (handle);
+  shader = handle;
   return shader->type;
 }
 
@@ -466,7 +467,7 @@ cogl_shader_is_compiled (CoglHandle handle)
   if (!cogl_is_shader (handle))
     return FALSE;
 
-  shader = _cogl_shader_pointer_from_handle (handle);
+  shader = handle;
 
 #ifdef HAVE_COGL_GL
   if (shader->language == COGL_SHADER_LANGUAGE_ARBFP)
