@@ -46,7 +46,7 @@
 #include <math.h>
 
 #ifdef COGL_HAS_WAYLAND_EGL_SERVER_SUPPORT
-#include <wayland-server.h>
+#include "cogl-wayland-server.h"
 #endif
 
 static void _cogl_texture_2d_free (CoglTexture2D *tex_2d);
@@ -313,12 +313,11 @@ cogl_texture_2d_new_from_data (CoglContext *ctx,
     rowstride = width * _cogl_pixel_format_get_bytes_per_pixel (format);
 
   /* Wrap the data into a bitmap */
-  bmp = _cogl_bitmap_new_from_data ((guint8 *)data,
-                                    format,
-                                    width,
-                                    height,
-                                    rowstride,
-                                    NULL, NULL);
+  bmp = cogl_bitmap_new_for_data (ctx,
+                                  width, height,
+                                  format,
+                                  rowstride,
+                                  (guint8 *) data);
 
   tex =_cogl_texture_2d_new_from_bitmap (bmp, COGL_TEXTURE_NONE,
                                          internal_format,
