@@ -51,10 +51,6 @@
 #include "cogl1-context.h"
 #include "cogl-offscreen.h"
 
-#ifndef GL_PACK_INVERT_MESA
-#define GL_PACK_INVERT_MESA 0x8758
-#endif
-
 #ifdef COGL_GL_DEBUG
 /* GL error to string conversion */
 static const struct {
@@ -79,7 +75,7 @@ static const struct {
 static const unsigned int n_gl_errors = G_N_ELEMENTS (gl_errors);
 
 const char *
-cogl_gl_error_to_string (GLenum error_code)
+_cogl_gl_error_to_string (GLenum error_code)
 {
   int i;
 
@@ -380,12 +376,13 @@ cogl_read_pixels (int x,
   int bpp = _cogl_pixel_format_get_bytes_per_pixel (format);
   CoglBitmap *bitmap;
 
-  bitmap = _cogl_bitmap_new_from_data (pixels,
-                                       format,
-                                       width, height,
-                                       bpp * width, /* rowstride */
-                                       NULL, /* destroy_fn */
-                                       NULL /* destroy_fn_data */);
+  _COGL_GET_CONTEXT (ctx, NO_RETVAL);
+
+  bitmap = cogl_bitmap_new_for_data (ctx,
+                                     width, height,
+                                     format,
+                                     bpp * width, /* rowstride */
+                                     pixels);
   cogl_framebuffer_read_pixels_into_bitmap (_cogl_get_read_framebuffer (),
                                             x, y,
                                             source,
@@ -561,15 +558,6 @@ cogl_set_projection_matrix (CoglMatrix *matrix)
   cogl_framebuffer_set_projection_matrix (cogl_get_draw_framebuffer (), matrix);
 }
 
-CoglClipState *
-_cogl_get_clip_state (void)
-{
-  CoglFramebuffer *framebuffer;
-
-  framebuffer = cogl_get_draw_framebuffer ();
-  return _cogl_framebuffer_get_clip_state (framebuffer);
-}
-
 GQuark
 _cogl_driver_error_quark (void)
 {
