@@ -105,9 +105,6 @@
 #if defined (COGL_HAS_EGL_PLATFORM_KMS_SUPPORT)
 #include <cogl/cogl-kms-renderer.h>
 #endif
-#if defined (COGL_HAS_EGL_PLATFORM_WAYLAND_SUPPORT)
-#include <cogl/cogl-wayland-renderer.h>
-#endif
 #if COGL_HAS_WIN32_SUPPORT
 #include <cogl/cogl-win32-renderer.h>
 #endif
@@ -124,7 +121,8 @@
  */
 #ifdef COGL_ENABLE_EXPERIMENTAL_2_0_API
 #include <cogl/cogl2-path.h>
-#include <cogl/cogl2-clip-state.h>
+/* This header will be removed in Cogl 1.12 */
+#include <cogl/cogl2-compatibility.h>
 #endif
 
 /*
