@@ -30,7 +30,6 @@
 #include "config.h"
 #endif
 
-#include "cogl.h"
 #include "cogl-util.h"
 #include "cogl-object.h"
 #include "cogl-internal.h"
@@ -44,6 +43,7 @@
 #include "cogl-primitives-private.h"
 #include "cogl-private.h"
 #include "cogl-attribute-private.h"
+#include "cogl1-context.h"
 #include "tesselator/tesselator.h"
 
 #include <string.h>
@@ -230,10 +230,12 @@ _cogl_path_stroke_nodes (CoglPath *path)
     {
       node = &g_array_index (data->path_nodes, CoglPathNode, path_start);
 
-      cogl_vdraw_attributes (COGL_VERTICES_MODE_LINE_STRIP,
-                             0, node->path_size,
-                             data->stroke_attributes[path_num],
-                             NULL);
+      cogl_framebuffer_vdraw_attributes (cogl_get_draw_framebuffer (),
+                                         source,
+                                         COGL_VERTICES_MODE_LINE_STRIP,
+                                         0, node->path_size,
+                                         data->stroke_attributes[path_num],
+                                         NULL);
 
       path_num++;
     }
@@ -322,8 +324,9 @@ void
 _cogl_path_fill_nodes (CoglPath *path, CoglDrawFlags flags)
 {
   gboolean needs_fallback = FALSE;
+  CoglPipeline *pipeline = cogl_get_source ();
 
-  _cogl_pipeline_foreach_layer_internal (cogl_get_source (),
+  _cogl_pipeline_foreach_layer_internal (pipeline,
                                          validate_layer_cb, &needs_fallback);
   if (needs_fallback)
     {
@@ -333,13 +336,15 @@ _cogl_path_fill_nodes (CoglPath *path, CoglDrawFlags flags)
 
   _cogl_path_build_fill_attribute_buffer (path);
 
-  _cogl_draw_indexed_attributes (COGL_VERTICES_MODE_TRIANGLES,
-                                 0, /* first_vertex */
-                                 path->data->fill_vbo_n_indices,
-                                 path->data->fill_vbo_indices,
-                                 path->data->fill_attributes,
-                                 COGL_PATH_N_ATTRIBUTES,
-                                 flags);
+  _cogl_framebuffer_draw_indexed_attributes (cogl_get_draw_framebuffer (),
+                                             pipeline,
+                                             COGL_VERTICES_MODE_TRIANGLES,
+                                             0, /* first_vertex */
+                                             path->data->fill_vbo_n_indices,
+                                             path->data->fill_vbo_indices,
+                                             path->data->fill_attributes,
+                                             COGL_PATH_N_ATTRIBUTES,
+                                             flags);
 }
 
 void
@@ -1262,6 +1267,8 @@ _cogl_path_build_fill_attribute_buffer (CoglPath *path)
   CoglPathData *data = path->data;
   int i;
 
+  _COGL_GET_CONTEXT (ctx, NO_RETVAL);
+
   /* If we've already got a vbo then we don't need to do anything */
   if (data->fill_attribute_buffer)
     return;
@@ -1347,7 +1354,8 @@ _cogl_path_build_fill_attribute_buffer (CoglPath *path)
   gluDeleteTess (tess.glu_tess);
 
   data->fill_attribute_buffer =
-    cogl_attribute_buffer_new (sizeof (CoglPathTesselatorVertex) *
+    cogl_attribute_buffer_new (ctx,
+                               sizeof (CoglPathTesselatorVertex) *
                                tess.vertices->len,
                                tess.vertices->data);
   g_array_free (tess.vertices, TRUE);
@@ -1367,7 +1375,8 @@ _cogl_path_build_fill_attribute_buffer (CoglPath *path)
                         2, /* n_components */
                         COGL_ATTRIBUTE_TYPE_FLOAT);
 
-  data->fill_vbo_indices = cogl_indices_new (tess.indices_type,
+  data->fill_vbo_indices = cogl_indices_new (ctx,
+                                             tess.indices_type,
                                              tess.indices->data,
                                              tess.indices->len);
   data->fill_vbo_n_indices = tess.indices->len;
@@ -1385,12 +1394,14 @@ _cogl_path_build_stroke_attribute_buffer (CoglPath *path)
   floatVec2 *buffer_p;
   unsigned int i;
 
+  _COGL_GET_CONTEXT (ctx, NO_RETVAL);
+
   /* If we've already got a cached vbo then we don't need to do anything */
   if (data->stroke_attribute_buffer)
     return;
 
   data->stroke_attribute_buffer =
-    cogl_attribute_buffer_new (data->path_nodes->len * sizeof (floatVec2),
+    cogl_attribute_buffer_new (ctx, data->path_nodes->len * sizeof (floatVec2),
                                NULL);
 
   buffer = COGL_BUFFER (data->stroke_attribute_buffer);
