@@ -1,4 +1,5 @@
 #include <cogl/cogl.h>
+#include <cogl/cogl-wayland-server.h>
 #include <glib.h>
 #include <stdio.h>
 #include <sys/time.h>
@@ -128,7 +129,7 @@ static GSourceFuncs wayland_event_source_funcs =
   NULL
 };
 
-GSource *
+static GSource *
 wayland_event_source_new (struct wl_event_loop *loop)
 {
   WaylandEventSource *source;
