@@ -11,7 +11,7 @@ typedef struct _TestState
   int width;
   int height;
 
-  CoglHandle tex[NUM_FBOS];
+  CoglTexture *tex[NUM_FBOS];
   CoglFramebuffer *fbo[NUM_FBOS];
 } TestState;
 
@@ -45,9 +45,12 @@ paint (TestState *state)
   /* Render all of the textures to the screen */
   for (i = 0; i < NUM_FBOS; i++)
     {
-      cogl_set_source_texture (state->tex[i]);
-      cogl_rectangle (2.0f / NUM_FBOS * i - 1.0f, -1.0f,
-                      2.0f / NUM_FBOS * (i + 1) - 1.0f, 1.0f);
+      CoglPipeline *pipeline = cogl_pipeline_new (ctx);
+      cogl_pipeline_set_layer_texture (pipeline, 0, state->tex[i]);
+      cogl_framebuffer_draw_rectangle (fb, pipeline,
+                                       2.0f / NUM_FBOS * i - 1.0f, -1.0f,
+                                       2.0f / NUM_FBOS * (i + 1) - 1.0f, 1.0f);
+      cogl_object_unref (pipeline);
     }
 
   /* Verify all of the fbos drew the right color */
@@ -58,7 +61,8 @@ paint (TestState *state)
           { 0x00, 0xff, 0x00, 0xff },
           { 0x00, 0x00, 0xff, 0xff } };
 
-      test_utils_check_pixel_rgb (state->width * (i + 0.5f) / NUM_FBOS,
+      test_utils_check_pixel_rgb (fb,
+                                  state->width * (i + 0.5f) / NUM_FBOS,
                                   state->height / 2,
                                   expected_colors[i][0],
                                   expected_colors[i][1],
@@ -67,18 +71,13 @@ paint (TestState *state)
 }
 
 void
-test_cogl_color_mask (TestUtilsGTestFixture *fixture,
-                      void *data)
+test_color_mask (void)
 {
-  TestUtilsSharedState *shared_state = data;
   TestState state;
-  CoglColor bg;
   int i;
 
-  state.width = cogl_framebuffer_get_width (shared_state->fb);
-  state.height = cogl_framebuffer_get_height (shared_state->fb);
-
-  cogl_color_init_from_4ub (&bg, 0, 0, 0, 255);
+  state.width = cogl_framebuffer_get_width (fb);
+  state.height = cogl_framebuffer_get_height (fb);
 
   for (i = 0; i < NUM_FBOS; i++)
     {
@@ -91,9 +90,8 @@ test_cogl_color_mask (TestUtilsGTestFixture *fixture,
         cogl_offscreen_new_to_texture (state.tex[i]));
 
       /* Clear the texture color bits */
-      cogl_push_framebuffer (state.fbo[i]);
-      cogl_clear (&bg, COGL_BUFFER_BIT_COLOR);
-      cogl_pop_framebuffer ();
+      cogl_framebuffer_clear4f (state.fbo[i],
+                                COGL_BUFFER_BIT_COLOR, 0, 0, 0, 1);
 
       cogl_framebuffer_set_color_mask (state.fbo[i],
                                        i == 0 ? COGL_COLOR_MASK_RED :
@@ -101,7 +99,11 @@ test_cogl_color_mask (TestUtilsGTestFixture *fixture,
                                        COGL_COLOR_MASK_BLUE);
     }
 
+  /* XXX: we have to push/pop a framebuffer since this test currently
+   * uses the legacy cogl_rectangle() api. */
+  cogl_push_framebuffer (fb);
   paint (&state);
+  cogl_pop_framebuffer ();
 
   if (cogl_test_verbose ())
     g_print ("OK\n");
